# Caja de Herramientas Importar Survey UAECD
Herramientas para la Precarga e Inyección de Encuestas de Actualización Catastral ArcGIS Survey 123 - ArcGIS Pro.
UAECD - Unidad Administrativa Especial de Catastro Distrital